{% load i18n %}
{% load static %}
<h3>Résultats du test</h3>
<div style="max-height: 250px; overflow: auto;">
  {% for e in evaluation %}
  {{e.string}} valeur = {{e.valeur}} label = {{e.label}}<br>
  {% endfor %}
</div>
