{% load i18n %}
{% load static %}
<style>
  .boutons-oranges {
      width: 450px;
      display: grid;
      grid-template-columns: repeat(5, 1fr);
      grid-gap: 5px;
  }
  .boutons-oranges button {
      background: orange;
      color: navy;
  }
</style>
<div class="boutons-oranges">
  {% for e in evaluation %}
  <button data-valeur="{{e.valeur}}" data-label="{{e.label}}"
	  onclick="new_text(this, '#new-text', '{{ e.mode }}')">
    {{e.label}}
  </button>
  {% endfor %}
</div>
