{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<h1>{% translate "Actions sur des listes d'élèves à choisir" %}</h1>
<div id="outils-choix">
  <fieldset class="frame">
    <legend class="strong">{% translate "Outils de choix" %}</legend>
    <fieldset class="subframe">
      <legend>{% translate "Un par un" %}</legend>
      <input id="nomprenom" name="nomprenom"
	     placeholder="{% translate 'NOM, Prénom' %}"
	     type="text" value="{{ nomprenom }}"/>
    </fieldset>
    <fieldset class="subframe">
      <legend>{% translate "choix par classe" %}</legend>
      <select id="cl" name="cl">
	<option value="">{% translate "--- selection ---" %}</option>
	{% for c in classes %}
	<option value="{{ c.libelle }}">{{ c }}</option>
	{% endfor %}
      </select>
    </fieldset>
    <fieldset class="subframe">
      <legend>{% translate "Au moins N livres prêtés" %}</legend>
      <label for="au_moins_pretes">
	{% translate 'Combien de livres au moins :' %}
      </label>
      <input id="au_moins_pretes" name="au_moins_pretes" style="width: 2em;"/>
    </fieldset>
    <fieldset class="subframe">
      <legend>{% translate "Au plus N livres prêtés" %}</legend>
      <label for="au_moins_nr">
	{% translate 'Combien de livres au moins :' %}
      </label>
      <input id="au_plus_pretes" name="au_plus_pretes" style="width: 2em;"/>
    </fieldset>
    <fieldset class="subframe">
      <legend>{% translate "A emprunté tel livre" %}</legend>
      <label for="code">
	{% translate 'code d&apos;un livre :' %}
      </label>
      <input id="code" name="code" style="width: 4em;"/>
    </fieldset>
    <fieldset class="subframe">
      <legend>{% translate "Mot-clé de message" %}</legend>
      <label for="cle">
	{% translate 'Mot_clé :' %}
      </label>
      <input id="cle" name="cle" style="width: 6em;"/>
    </fieldset>
  </fieldset>
</div>
<div id="les_choix">
  <fieldset class="frame">
    <legend class="strong">{% translate "Liste d'élèves" %}</legend>
    <div id="choix"><div>
  </fieldset>
</div>
<div id="actions">
  <fieldset class="frame">
    <legend class="strong">{% translate "Actions" %}</legend>
    <button onclick="action_courrier()">
      <img alt="Préparer des courriers"
	   src="{% static '/img/lettre.svg' %}"
	   title="{% translate 'Préparer des courriers' %}"
	   style="height: 50px;"/>
    </button>
  </fieldset>
</div>

<script>
  choix_eleves_init();
</script>
{% endblock %}

