{% load i18n %}
<p>
  {% translate "L'élève" %}
  {{ caution.nom }} {{ caution.prenom }}
  {% translate "ne se présentera pas ... Veuillez rappeler son numéro de caution." %}
</p>
<fieldset>
  <legend>
    {% translate "Rappel" %}
  </legend>
  <label for="n">
    {% translate "Numéro :" %}
  </label>
  <input id="n" placeholder="0123456" />
</fielset>
