{% load i18n %}
<p>
 {% translate "rendue, le" %} {{ c.rendue_le|date:'j F Y'}}{% translate "." %}
</p>
<p>
  {% translate "Avec un chèque de" %}
  {{ c.somme_rendue|floatformat:2}}{% translate " €" %}
</p>
<table>
  {% for p in props %}
  <tr>
    <td>
      <input type="checkbox" {% if p.check %}checked{% endif %}
	     disabled="true"/>
    </td>
    <td>
      {{ p.text }}
    </td>
  </tr>
  {% endfor %}
  <tr>
    <td colspan="2">
      {% translate "Commentaire :" %}<br>
      {{ c.commentaire }}
    </td>
  </tr>
</table>
