{% extends 'gestion/base.html' %}
{% load i18n %}


{% block contents %}
<h3>Statut : {{ statut }}</h3>
<div id="en-stock" class="flexcontainer manuels"
     style="max-height: 200px; overflow: scroll;
	    background: white; border:1px solid navy;
	    padding: 3px 5px;">
</div>

<script>
  manuels_statut_init()
</script>
{% endblock %}

