{% extends 'gestion/base.html' %}
{% load i18n %}


{% block contents %}
<ul>
  <li>
    <a href="/revue_du_stock">
      {% translate "revue du stock" %}
    </a>
  </li>
  <li>
    <a href="/manuels_statut/en-stock">
      {% translate "manuels flashés dans le stock" %}
    </a>
  </li>
</ul>
{% endblock %}

