{% load i18n %}
<div id="livres-a-prendre" class="mini">
  <h3 onclick="toggle_lap()">
    {% if livres %}
    {% translate "Livres à prendre" %}
    {% else %}
    {% translate "Tous les livres semblent prêtés selon la prévision" %}
    {% endif %}
  </h3>
  <ol>
    {% for l in livres %}
    <li>{{ l.titre }} ({{ l.categories }} [{% translate "abrégé" %} = {{ l.abrege }}])</li>
    {% endfor %}
  </ol>
</div>
