{% load i18n %}
<p>
 {% translate "La somme à rendre est diminuée quand des manuels sont perdus : voir la fiche-mémoire." %}
</p>
<fieldset>
 <table>
  <tr>
   <td>
    {% translate "Somme à rendre :" %}
   </td>
   <td>
    <input id="somme" name="somme" placeholder="{% translate '0,00' %}" type="text" value="{{ a_rendre|floatformat:2 }}"/>
    {% translate " €" %}
   </td>
  </tr>
  <tr>
    <td>
      {% translate "Remarques :" %}
    </td>
    <td>
      <input type="checkbox" id="inconnu" name="inconnu"/>
      <label for="inconnu">{% translate "Cette personne n'est jamais venue" %}</label>
      <br>
      <input type="checkbox" id="reussite" name="reussite"/>
      <label for="reussite">{% translate "Réussite aux examens" %}</label>
      <br>
      <input type="checkbox" id="perte" name="perte"/>
      <label for="perte">{% translate "Livre(s) perdu(s)" %}</label>
      <br>
      <input type="checkbox" id="quitte" name="quitte"/>
      <label for="quitte">{% translate "Quitte l'établissement" %}</label>
      <br>
      <input type="checkbox" id="sc" name="sc"/>
      <label for="sc">{% translate "Sans caution" %}</label>
      <br>
      <input type="checkbox" id="autre" name="autre"/>
      <label for="autre">{% translate "Autre" %}</label>
      <input type="text" id="comment" name="comment"
	     disabled='disabled' />
      <br>
   </td>
  </tr>
  {% if no_caution == "0" %}
  <tr>
   <td>
    {% translate "Numéro de caution :" %}
   </td>
   <td>
    <input id="numero_de_la_caution" name="numero" placeholder="{% translate '12345' %}" type="text" value="{{ no_caution }}"/>
   </td>
  </tr>
  {% else %}
  <tr style="display: none;">
   <td>
    {% translate "Numéro de caution :" %}
   </td>
   <td>
    <input id="numero_de_la_caution" name="numero" placeholder="{% translate '12345' %}" type="text" value="{{ no_caution }}"/>
   </td>
  </tr>
  {% endif %}
 </table>
</fieldset>
<script>
  $("#autre").on("change", function(ev){
      if ($(ev.target).prop("checked") == true){
	  $("#comment").prop("disabled", false).
	      attr("placeholder", "{% translate 'Précisez ...' %}")
      } else {
	  $("#comment").prop("disabled", true).
	      attr("placeholder", "").val("")
      }
  })
  if ("{{ perdus }}" == "True") $("#perte").prop("checked", true)
</script>
